@@ -100,7 +100,7 @@ def compare_object(x, y, context, ignore_attributes=()):
     y_attrs = _extract_attrs(y, _attrs_to_ignore(context, ignore_attributes, y))
     if x_attrs is None or y_attrs is None or not (x_attrs and y_attrs):
         return compare_simple(x, y, context)
-    if x_attrs != y_attrs:
+    if context.ignore_eq or x_attrs != y_attrs:
         return _compare_mapping(x_attrs, y_attrs, context, x,
                                 'attributes ', '.%s')
 
@@ -377,9 +377,23 @@ def compare_call(x, y, context):
 
     x_name, x_args, x_kw = extract(x)
     y_name, y_args, y_kw = extract(y)
+
     if x_name == y_name and x_args == y_args and x_kw == y_kw:
         return compare_call(getattr(x, parent_name), getattr(y, parent_name), context)
-    return compare_text(repr(x), repr(y), context)
+
+    if repr(x) != repr(y):
+        return compare_text(repr(x), repr(y), context)
+
+    different = (
+        context.different(x_name, y_name, ' function name') or
+        context.different(x_args, y_args, ' args') or
+        context.different(x_kw, y_kw, ' kw')
+    )
+    if not different:
+        return
+
+    return 'mock.call not as expected:'
+
 
 
 def compare_partial(x, y, context):
